==> rhdm-7.1.1-sources.zip: src/kie-wb-common-7.11.0.Final-redhat-00004/kie-wb-common-dmn/kie-wb-common-dmn-client/src/main/java/org/kie/workbench/common/dmn/client/resources/i18n/DMNEditorConstants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.workbench.common.dmn.client.resources.i18n;

import org.jboss.errai.ui.shared.api.annotations.TranslationKey;

public class DMNEditorConstants {

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_ReturnToDRG = "ExpressionEditor.ReturnToDRG";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_UndefinedExpressionType = "ExpressionEditor.UndefinedExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_LiteralExpressionType = "ExpressionEditor.LiteralExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_ContextExpressionType = "ExpressionEditor.ContextExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_DecisionTableExpressionType = "ExpressionEditor.DecisionTableExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_RelationType = "ExpressionEditor.RelationType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_FunctionType = "ExpressionEditor.FunctionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_PMMLFunctionType = "ExpressionEditor.PMMLFunctionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_JavaFunctionType = "ExpressionEditor.JavaFunctionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_InvocationType = "ExpressionEditor.InvocationType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_Clear = "ExpressionEditor.Clear";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_InsertContextEntryAbove = "ContextEditor.InsertContextEntryAbove";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_InsertContextEntryBelow = "ContextEditor.InsertContextEntryBelow";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_DeleteContextEntry = "ContextEditor.DeleteContextEntry";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertRowAbove = "RelationEditor.InsertRowAbove";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertRowBelow = "RelationEditor.InsertRowBelow";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_DeleteRow = "RelationEditor.DeleteRow";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertColumnLeft = "RelationEditor.InsertColumnLeft";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertColumnRight = "RelationEditor.InsertColumnRight";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_DeleteColumn = "RelationEditor.DeleteColumn";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_InsertParameterAbove = "InvocationEditor.InsertParameterAbove";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_InsertParameterBelow = "InvocationEditor.InsertParameterBelow";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_DeleteParameter = "InvocationEditor.DeleteParameter";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_FEEL = "FunctionEditor.FEEL";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_JAVA = "FunctionEditor.JAVA";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_PMML = "FunctionEditor.PMML";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_Undefined = "FunctionEditor.Undefined";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DescriptionColumnHeader = "DecisionTableEditor.DescriptionColumnHeader";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_OutputClauseHeader = "DecisionTableEditor.OutputClauseHeader";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertDecisionRuleAbove = "DecisionTableEditor.InsertDecisionRuleAbove";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertDecisionRuleBelow = "DecisionTableEditor.InsertDecisionRuleBelow";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DeleteDecisionRule = "DecisionTableEditor.DeleteDecisionRule";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertInputClauseLeft = "DecisionTableEditor.InsertInputClauseLeft";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertInputClauseRight = "DecisionTableEditor.InsertInputClauseRight";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DeleteInputClause = "DecisionTableEditor.DeleteInputClause";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertOutputClauseLeft = "DecisionTableEditor.InsertOutputClauseLeft";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertOutputClauseRight = "DecisionTableEditor.InsertOutputClauseRight";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DeleteOutputClause = "DecisionTableEditor.DeleteOutputClause";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_NullBuiltinAggregator = "DecisionTableEditor.NullBuiltinAggregator";

    @TranslationKey(defaultValue = "")
    public static final String DecisionNavigatorPresenter_DecisionNavigator = "DecisionNavigatorPresenter.DecisionNavigator";

    @TranslationKey(defaultValue = "")
    public static final String DecisionNavigatorBaseItemFactory_NoName = "DecisionNavigatorBaseItemFactory.NoName";

    @TranslationKey(defaultValue = "")
    public static final String TypePickerWidget_Choose = "TypePickerWidget.Choose";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeFactory_None = "DataTypeFactory.None";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeFactory_Structure = "DataTypeFactory.Structure";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeSelectView_DefaultTitle = "DataTypeSelectView.DefaultTitle";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeSelectView_CustomTitle = "DataTypeSelectView.CustomTitle";
}

==> rhdm-7.2.1-sources.zip: src/kie-wb-common-7.14.0.Final-redhat-00004/kie-wb-common-dmn/kie-wb-common-dmn-client/src/main/java/org/kie/workbench/common/dmn/client/resources/i18n/DMNEditorConstants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.workbench.common.dmn.client.resources.i18n;

import org.jboss.errai.ui.shared.api.annotations.TranslationKey;

public class DMNEditorConstants {

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_ReturnToDRG = "ExpressionEditor.ReturnToDRG";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_UndefinedExpressionType = "ExpressionEditor.UndefinedExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_LiteralExpressionType = "ExpressionEditor.LiteralExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_ContextExpressionType = "ExpressionEditor.ContextExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_DecisionTableExpressionType = "ExpressionEditor.DecisionTableExpressionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_RelationType = "ExpressionEditor.RelationType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_FunctionType = "ExpressionEditor.FunctionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_PMMLFunctionType = "ExpressionEditor.PMMLFunctionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_JavaFunctionType = "ExpressionEditor.JavaFunctionType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_InvocationType = "ExpressionEditor.InvocationType";

    @TranslationKey(defaultValue = "")
    public static final String ExpressionEditor_Clear = "ExpressionEditor.Clear";

    @TranslationKey(defaultValue = "")
    public static final String LiteralExpression_EditExpression = "LiteralExpression.EditExpression";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_InsertContextEntryAbove = "ContextEditor.InsertContextEntryAbove";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_InsertContextEntryBelow = "ContextEditor.InsertContextEntryBelow";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_DeleteContextEntry = "ContextEditor.DeleteContextEntry";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_EditExpression = "ContextEditor.EditExpression";

    @TranslationKey(defaultValue = "")
    public static final String ContextEditor_EditContextEntry = "ContextEditor.EditContextEntry";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertRowAbove = "RelationEditor.InsertRowAbove";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertRowBelow = "RelationEditor.InsertRowBelow";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_DeleteRow = "RelationEditor.DeleteRow";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertColumnLeft = "RelationEditor.InsertColumnLeft";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_InsertColumnRight = "RelationEditor.InsertColumnRight";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_DeleteColumn = "RelationEditor.DeleteColumn";

    @TranslationKey(defaultValue = "")
    public static final String RelationEditor_EditRelation = "RelationEditor.EditRelation";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_InsertParameterAbove = "InvocationEditor.InsertParameterAbove";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_InsertParameterBelow = "InvocationEditor.InsertParameterBelow";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_DeleteParameter = "InvocationEditor.DeleteParameter";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_EditExpression = "InvocationEditor.EditExpression";

    @TranslationKey(defaultValue = "")
    public static final String InvocationEditor_EditParameter = "InvocationEditor.EditParameter";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_FEEL = "FunctionEditor.FEEL";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_JAVA = "FunctionEditor.JAVA";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_PMML = "FunctionEditor.PMML";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_Undefined = "FunctionEditor.Undefined";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_EditExpression = "FunctionEditor.EditExpression";

    @TranslationKey(defaultValue = "")
    public static final String FunctionEditor_EditParameters = "FunctionEditor.EditParameters";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DescriptionColumnHeader = "DecisionTableEditor.DescriptionColumnHeader";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_OutputClauseHeader = "DecisionTableEditor.OutputClauseHeader";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertDecisionRuleAbove = "DecisionTableEditor.InsertDecisionRuleAbove";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertDecisionRuleBelow = "DecisionTableEditor.InsertDecisionRuleBelow";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DeleteDecisionRule = "DecisionTableEditor.DeleteDecisionRule";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertInputClauseLeft = "DecisionTableEditor.InsertInputClauseLeft";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertInputClauseRight = "DecisionTableEditor.InsertInputClauseRight";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DeleteInputClause = "DecisionTableEditor.DeleteInputClause";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertOutputClauseLeft = "DecisionTableEditor.InsertOutputClauseLeft";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_InsertOutputClauseRight = "DecisionTableEditor.InsertOutputClauseRight";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DeleteOutputClause = "DecisionTableEditor.DeleteOutputClause";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_NullBuiltinAggregator = "DecisionTableEditor.NullBuiltinAggregator";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_EditHitPolicy = "DecisionTableEditor.EditHitPolicy";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_EditInputClause = "DecisionTableEditor.EditInputClause";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_EditOutputClause = "DecisionTableEditor.EditOutputClause";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_HitPolicyLabel = "DecisionTableEditor.HitPolicyLabel";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_BuiltinAggregatorLabel = "DecisionTableEditor.BuiltinAggregatorLabel";

    @TranslationKey(defaultValue = "")
    public static final String DecisionTableEditor_DecisionTableOrientationLabel = "DecisionTableEditor.DecisionTableOrientationLabel";

    @TranslationKey(defaultValue = "")
    public static final String DecisionNavigatorPresenter_DecisionNavigator = "DecisionNavigatorPresenter.DecisionNavigator";

    @TranslationKey(defaultValue = "")
    public static final String DecisionNavigatorBaseItemFactory_NoName = "DecisionNavigatorBaseItemFactory.NoName";

    @TranslationKey(defaultValue = "")
    public static final String TypePickerWidget_Choose = "TypePickerWidget.Choose";

    @TranslationKey(defaultValue = "")
    public static final String TypePickerWidget_Manage = "TypePickerWidget.Manage";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeManager_None = "DataTypeManager.None";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeManager_Structure = "DataTypeManager.Structure";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeSelectView_DefaultTitle = "DataTypeSelectView.DefaultTitle";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeSelectView_CustomTitle = "DataTypeSelectView.CustomTitle";

    @TranslationKey(defaultValue = "")
    public static final String NameAndDataTypePopover_NameLabel = "NameAndDataTypePopover.NameLabel";

    @TranslationKey(defaultValue = "")
    public static final String NameAndDataTypePopover_DataTypeLabel = "NameAndDataTypePopover.DataTypeLabel";

    @TranslationKey(defaultValue = "")
    public static final String NameIsBlankErrorMessage_StrongMessage = "NameIsBlankErrorMessage.StrongMessage";

    @TranslationKey(defaultValue = "")
    public static final String NameIsBlankErrorMessage_RegularMessage = "NameIsBlankErrorMessage.RegularMessage";

    @TranslationKey(defaultValue = "")
    public static final String NameIsNotUniqueErrorMessage_StrongMessage = "NameIsNotUniqueErrorMessage.StrongMessage";

    @TranslationKey(defaultValue = "")
    public static final String NameIsNotUniqueErrorMessage_RegularMessage = "NameIsNotUniqueErrorMessage.RegularMessage";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeWithFieldsWarningMessage_StrongMessage = "DataTypeWithFieldsWarningMessage.StrongMessage";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeWithFieldsWarningMessage_RegularMessage = "DataTypeWithFieldsWarningMessage.RegularMessage";

    @TranslationKey(defaultValue = "")
    public static final String ReferencedDataTypeWarningMessage_StrongMessage = "ReferencedDataTypeWarningMessage.StrongMessage";

    @TranslationKey(defaultValue = "")
    public static final String ReferencedDataTypeWarningMessage_RegularMessage = "ReferencedDataTypeWarningMessage.RegularMessage";

    @TranslationKey(defaultValue = "")
    public static final String NameIsDefaultTypeMessage_StrongMessage = "NameIsDefaultTypeMessage.StrongMessage";

    @TranslationKey(defaultValue = "")
    public static final String NameIsDefaultTypeMessage_RegularMessage = "NameIsDefaultTypeMessage.RegularMessage";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeConstraintView_ConstraintsTooltip = "DataTypeConstraintView.ConstraintsTooltip";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeListItemView_Constraints = "DataTypeListItemView.Constraints";

    @TranslationKey(defaultValue = "")
    public static final String DataTypeListItemView_Collection = "DataTypeListItemView.Collection";

    @TranslationKey(defaultValue = "")
    public static final String SmallSwitchComponentView_Yes = "SmallSwitchComponentView.Yes";

    @TranslationKey(defaultValue = "")
    public static final String SmallSwitchComponentView_No = "SmallSwitchComponentView.No";
}
